dk.simongray.drop-in-search.indexing

The segments of an index, and how adding and removing documents changes them, as in Lucene's index, https://lucene.apache.org/core/9_11_1/core/

An index is a map of:

  • :segments, a vector of its segments
  • :docs, a map of each id to the index of its segment and its number there
  • :fields, a map of each field to its number
  • :defaults, the options of its queries, if any

Its :term-fn, if any, is in its metadata, since a function can't be printed with it.

The segments of an index, and how adding and removing documents changes
them, as in Lucene's index, https://lucene.apache.org/core/9_11_1/core/

An index is a map of:

- :segments, a vector of its segments
- :docs, a map of each id to the index of its segment and its number
  there
- :fields, a map of each field to its number
- :defaults, the options of its queries, if any

Its :term-fn, if any, is in its metadata, since a function can't be
printed with it.
raw docstring

No vars found in this namespace.

cljdoc builds & hosts documentation for Clojure/Script libraries