dk.simongray.drop-in-search.matching

The documents of each segment of an index that match a prepared query, and their scores, its clauses combined as in Lucene's BooleanQuery, https://lucene.apache.org/core/9_11_1/core/

The documents of each segment of an index that match a prepared query,
and their scores, its clauses combined as in Lucene's BooleanQuery,
https://lucene.apache.org/core/9_11_1/core/
raw docstring

No vars found in this namespace.

cljdoc builds & hosts documentation for Clojure/Script libraries