dk.simongray.drop-in-search.scoring

BM25F's scores of the documents of a segment that hold a term, from the weights and lengths of their fields.

The comments name the source of each part, and where it departs from it:

BM25F's scores of the documents of a segment that hold a term, from the
weights and lengths of their fields.

The comments name the source of each part, and where it departs from it:

- Robertson and Zaragoza, The Probabilistic Relevance Framework: BM25
  and Beyond, Foundations and Trends in Information Retrieval 3(4),
  2009, https://www.staff.city.ac.uk/~sbrp622/papers/foundations_bm25_review.pdf
- Lucene's BM25Similarity, https://lucene.apache.org/core/9_11_1/core/
raw docstring

No vars found in this namespace.

cljdoc builds & hosts documentation for Clojure/Script libraries