The documents of each segment of an index that match a prepared query, and their scores, its clauses combined as in Lucene's BooleanQuery, https://lucene.apache.org/core/9_11_1/core/
The documents of each segment of an index that match a prepared query, and their scores, its clauses combined as in Lucene's BooleanQuery, https://lucene.apache.org/core/9_11_1/core/
No vars found in this namespace.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |